@@ -1,4 +1,5 @@
 import urllib.request
+from datetime  import datetime
 from typing    import List, Optional, Tuple, Union
 
 from httpx     import AsyncClient
@@ -12,9 +13,11 @@ HEADERS = {"Content-Type": "text/xml"}
 class BaseDroneBL(object):
     def __init__(self,
             key:     str,
-            timeout: float = 10.0):
+            timeout: float = 10.0,
+            xmlrpc2: str   = URL):
         self._key     = key.encode("ascii")
         self._timeout = timeout
+        self._xmlrpc2 = xmlrpc2
 
     def batch(self) -> make.Batch:
         return make.Batch()
@@ -26,16 +29,23 @@ class DroneBL(BaseDroneBL):
             method: bytes
             ) -> bytes:
         data     = make.request(self._key, method)
-        request  = urllib.request.Request(URL, data, HEADERS, method="POST")
+        request  = urllib.request.Request(
+            self._xmlrpc2,
+            data,
+            HEADERS,
+            method="POST"
+        )
         response = urllib.request.urlopen(request, timeout=self._timeout)
         return response.read()
 
     def lookup(self,
-            query: Union[str, int],
-            type:  Optional[int]=None,
-            limit: Optional[int]=None
+            query:  Union[str, int],
+            type:   Optional[int]=None,
+            limit:  Optional[int]=None,
+            listed: Optional[bool]=None,
+            stop:   Optional[datetime]=None
             ) -> List[Lookup]:
-        method    = make.lookup(query, type, limit)
+        method    = make.lookup(query, type, limit, listed, stop)
         responses = self._post(method)
         return parse.lookup(responses)
 
@@ -80,16 +90,21 @@ class AsyncDroneBL(BaseDroneBL):
         data = make.request(self._key, method)
         async with AsyncClient() as client:
             response = await client.post(
-                URL, data=data, headers=HEADERS, timeout=self._timeout
+                self._xmlrpc2,
+                data=data,
+                headers=HEADERS,
+                timeout=self._timeout
             )
         return response.content
 
     async def lookup(self,
-            query: Union[str, int],
-            type:  Optional[int]=None,
-            limit: Optional[int]=None
+            query:  Union[str, int],
+            type:   Optional[int]=None,
+            limit:  Optional[int]=None,
+            listed: Optional[bool]=None,
+            stop:   Optional[datetime]=None
             ) -> List[Lookup]:
-        method    = make.lookup(query, type, limit)
+        method    = make.lookup(query, type, limit, listed, stop)
         responses = await self._post(method)
         return parse.lookup(responses)
 
