@@ -1,3 +1,4 @@
+from datetime  import datetime
 from typing    import List, Optional, Union
 from xml.etree import ElementTree as et
 
@@ -10,12 +11,22 @@ def request(
     return ENVELOPE % (key, method)
 
 def lookup(
-        query: Union[str, int],
-        type:  Optional[int]=None,
-        limit: Optional[int]=None
+        query:  Union[str, int],
+        type:   Optional[int]=None,
+        limit:  Optional[int]=None,
+        listed: Optional[bool]=None,
+        stop:   Optional[datetime]=None
         ) -> bytes:
+
+    if listed == True:
+        listedp = "1"
+    elif listed == False:
+        listedp = "0"
+    else:
+        listedp = "2"
+
     element = et.Element("lookup", {
-        "listed": "1"
+        "listed": listedp
     })
 
     if isinstance(query, int):
@@ -29,6 +40,9 @@ def lookup(
     if limit is not None:
         element.set("limit", str(limit))
 
+    if stop is not None:
+        element.set("stop", str(int(stop.timestamp())))
+
     return et.tostring(element)
 
 def add(
